@@ -23,9 +23,9 @@ echo "Generating configuration files for $package, please wait...."
 echo "  libtoolize"
 libtoolize -c -f
 echo "  aclocal $ACLOCAL_FLAGS"
-aclocal $ACLOCAL_FLAGS
+aclocal $ACLOCAL_FLAGS  || exit 1
 echo "  running autoconf"
-autoconf
+autoconf || exit 1
 
 if test -z "$*"; then
         echo "I am going to run ./configure with no arguments - if you wish "
