@@ -169,7 +169,7 @@ for d in all_diffs:
 length = len(list)
 if length > 0:
     print
-    print myself,new_name,"differences from baseline""(",str(length)," differences)"
+    print myself,new_name,"differences from baseline ("+str(length)+" differences)"
     list.sort()
     for l in list:
         print "%s %s (%s/%d/%s)" % (l[0], l[1], l[2], l[3], l[4])
