@@ -102,7 +102,7 @@ if __name__ == "__main__":
     revision_value=options.revision_value
 
     if revision != "HEAD":
-        gsconf.checksumdb = gsconf.dailydir+revision+".db"
+        gsconf.checksumdb = gsconf.dailydir+revision # mhw +".db"
 
     if revision != "HEAD":
         gsroot=gsconf.root+"gs."+revision+"/"
@@ -123,6 +123,7 @@ if __name__ == "__main__":
     testAll(options.track,gsroot,now,options)
 
     if options.track:
+        dbname = dbname + ".db" # mhw
         if not os.path.exists(dbname):
             print options.myself,"ERROR","the checksum database does not exist",dbname
 
